==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/EnergyPerformance.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PERIODUOM_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPOWERFACTOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPEAKDEMAND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLINGPERIODSTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLEVERYPERIOD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLEVERYUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERFORMANCEMANAGER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ELECTRICSUBMETERINTERVAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ELECTRICUSAGETHRESHOLD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "targetpowerfactor",
    "targetpeakdemand",
    "billingperiodstartdate",
    "billeveryperiod",
    "billeveryuom",
    "phaseimbalanceefficiencyloss1",
    "phaseimbalanceefficiencyloss2",
    "phaseimbalanceefficiencyloss3",
    "phaseimbalanceefficiencyloss4",
    "phaseimbalanceefficiencyloss5",
    "performancemanager",
    "electricsubmeterinterval",
    "electricusagethreshold"
})
@XmlRootElement(name = "EnergyPerformance")
public class EnergyPerformance {

    @XmlElement(name = "TARGETPOWERFACTOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY targetpowerfactor;
    @XmlElement(name = "TARGETPEAKDEMAND", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY targetpeakdemand;
    @XmlElement(name = "BILLINGPERIODSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME billingperiodstartdate;
    @XmlElement(name = "BILLEVERYPERIOD", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY billeveryperiod;
    @XmlElement(name = "BILLEVERYUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERIODUOM_Type billeveryuom;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS1", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss1;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS2", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss2;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS3", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss3;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS4", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss4;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS5", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss5;
    @XmlElement(name = "PERFORMANCEMANAGER", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type performancemanager;
    @XmlElement(name = "ELECTRICSUBMETERINTERVAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY electricsubmeterinterval;
    @XmlElement(name = "ELECTRICUSAGETHRESHOLD", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY electricusagethreshold;

    /**
     * Obtient la valeur de la propriété targetpowerfactor.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTARGETPOWERFACTOR() {
        return targetpowerfactor;
    }

    /**
     * Définit la valeur de la propriété targetpowerfactor.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTARGETPOWERFACTOR(QUANTITY value) {
        this.targetpowerfactor = value;
    }

    /**
     * Obtient la valeur de la propriété targetpeakdemand.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTARGETPEAKDEMAND() {
        return targetpeakdemand;
    }

    /**
     * Définit la valeur de la propriété targetpeakdemand.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTARGETPEAKDEMAND(QUANTITY value) {
        this.targetpeakdemand = value;
    }

    /**
     * Obtient la valeur de la propriété billingperiodstartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getBILLINGPERIODSTARTDATE() {
        return billingperiodstartdate;
    }

    /**
     * Définit la valeur de la propriété billingperiodstartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setBILLINGPERIODSTARTDATE(DATETIME value) {
        this.billingperiodstartdate = value;
    }

    /**
     * Obtient la valeur de la propriété billeveryperiod.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBILLEVERYPERIOD() {
        return billeveryperiod;
    }

    /**
     * Définit la valeur de la propriété billeveryperiod.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBILLEVERYPERIOD(QUANTITY value) {
        this.billeveryperiod = value;
    }

    /**
     * Obtient la valeur de la propriété billeveryuom.
     * 
     * @return
     *     possible object is
     *     {@link PERIODUOM_Type }
     *     
     */
    public PERIODUOM_Type getBILLEVERYUOM() {
        return billeveryuom;
    }

    /**
     * Définit la valeur de la propriété billeveryuom.
     * 
     * @param value
     *     allowed object is
     *     {@link PERIODUOM_Type }
     *     
     */
    public void setBILLEVERYUOM(PERIODUOM_Type value) {
        this.billeveryuom = value;
    }

    /**
     * Obtient la valeur de la propriété phaseimbalanceefficiencyloss1.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS1() {
        return phaseimbalanceefficiencyloss1;
    }

    /**
     * Définit la valeur de la propriété phaseimbalanceefficiencyloss1.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS1(QUANTITY value) {
        this.phaseimbalanceefficiencyloss1 = value;
    }

    /**
     * Obtient la valeur de la propriété phaseimbalanceefficiencyloss2.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS2() {
        return phaseimbalanceefficiencyloss2;
    }

    /**
     * Définit la valeur de la propriété phaseimbalanceefficiencyloss2.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS2(QUANTITY value) {
        this.phaseimbalanceefficiencyloss2 = value;
    }

    /**
     * Obtient la valeur de la propriété phaseimbalanceefficiencyloss3.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS3() {
        return phaseimbalanceefficiencyloss3;
    }

    /**
     * Définit la valeur de la propriété phaseimbalanceefficiencyloss3.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS3(QUANTITY value) {
        this.phaseimbalanceefficiencyloss3 = value;
    }

    /**
     * Obtient la valeur de la propriété phaseimbalanceefficiencyloss4.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS4() {
        return phaseimbalanceefficiencyloss4;
    }

    /**
     * Définit la valeur de la propriété phaseimbalanceefficiencyloss4.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS4(QUANTITY value) {
        this.phaseimbalanceefficiencyloss4 = value;
    }

    /**
     * Obtient la valeur de la propriété phaseimbalanceefficiencyloss5.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS5() {
        return phaseimbalanceefficiencyloss5;
    }

    /**
     * Définit la valeur de la propriété phaseimbalanceefficiencyloss5.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS5(QUANTITY value) {
        this.phaseimbalanceefficiencyloss5 = value;
    }

    /**
     * Obtient la valeur de la propriété performancemanager.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getPERFORMANCEMANAGER() {
        return performancemanager;
    }

    /**
     * Définit la valeur de la propriété performancemanager.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setPERFORMANCEMANAGER(PERSONID_Type value) {
        this.performancemanager = value;
    }

    /**
     * Obtient la valeur de la propriété electricsubmeterinterval.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getELECTRICSUBMETERINTERVAL() {
        return electricsubmeterinterval;
    }

    /**
     * Définit la valeur de la propriété electricsubmeterinterval.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setELECTRICSUBMETERINTERVAL(QUANTITY value) {
        this.electricsubmeterinterval = value;
    }

    /**
     * Obtient la valeur de la propriété electricusagethreshold.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getELECTRICUSAGETHRESHOLD() {
        return electricusagethreshold;
    }

    /**
     * Définit la valeur de la propriété electricusagethreshold.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setELECTRICUSAGETHRESHOLD(QUANTITY value) {
        this.electricusagethreshold = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/EnergyPerformance.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PERIODUOM_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPOWERFACTOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPEAKDEMAND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLINGPERIODSTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLEVERYPERIOD" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BILLEVERYUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHASEIMBALANCEEFFICIENCYLOSS5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERFORMANCEMANAGER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ELECTRICSUBMETERINTERVAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ELECTRICUSAGETHRESHOLD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "targetpowerfactor",
    "targetpeakdemand",
    "billingperiodstartdate",
    "billeveryperiod",
    "billeveryuom",
    "phaseimbalanceefficiencyloss1",
    "phaseimbalanceefficiencyloss2",
    "phaseimbalanceefficiencyloss3",
    "phaseimbalanceefficiencyloss4",
    "phaseimbalanceefficiencyloss5",
    "performancemanager",
    "electricsubmeterinterval",
    "electricusagethreshold"
})
@XmlRootElement(name = "EnergyPerformance")
public class EnergyPerformance {

    @XmlElement(name = "TARGETPOWERFACTOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY targetpowerfactor;
    @XmlElement(name = "TARGETPEAKDEMAND", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY targetpeakdemand;
    @XmlElement(name = "BILLINGPERIODSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME billingperiodstartdate;
    @XmlElement(name = "BILLEVERYPERIOD", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY billeveryperiod;
    @XmlElement(name = "BILLEVERYUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERIODUOM_Type billeveryuom;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS1", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss1;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS2", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss2;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS3", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss3;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS4", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss4;
    @XmlElement(name = "PHASEIMBALANCEEFFICIENCYLOSS5", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY phaseimbalanceefficiencyloss5;
    @XmlElement(name = "PERFORMANCEMANAGER", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type performancemanager;
    @XmlElement(name = "ELECTRICSUBMETERINTERVAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY electricsubmeterinterval;
    @XmlElement(name = "ELECTRICUSAGETHRESHOLD", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY electricusagethreshold;

    /**
     * Gets the value of the targetpowerfactor property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTARGETPOWERFACTOR() {
        return targetpowerfactor;
    }

    /**
     * Sets the value of the targetpowerfactor property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTARGETPOWERFACTOR(QUANTITY value) {
        this.targetpowerfactor = value;
    }

    /**
     * Gets the value of the targetpeakdemand property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTARGETPEAKDEMAND() {
        return targetpeakdemand;
    }

    /**
     * Sets the value of the targetpeakdemand property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTARGETPEAKDEMAND(QUANTITY value) {
        this.targetpeakdemand = value;
    }

    /**
     * Gets the value of the billingperiodstartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getBILLINGPERIODSTARTDATE() {
        return billingperiodstartdate;
    }

    /**
     * Sets the value of the billingperiodstartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setBILLINGPERIODSTARTDATE(DATETIME value) {
        this.billingperiodstartdate = value;
    }

    /**
     * Gets the value of the billeveryperiod property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBILLEVERYPERIOD() {
        return billeveryperiod;
    }

    /**
     * Sets the value of the billeveryperiod property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBILLEVERYPERIOD(QUANTITY value) {
        this.billeveryperiod = value;
    }

    /**
     * Gets the value of the billeveryuom property.
     * 
     * @return
     *     possible object is
     *     {@link PERIODUOM_Type }
     *     
     */
    public PERIODUOM_Type getBILLEVERYUOM() {
        return billeveryuom;
    }

    /**
     * Sets the value of the billeveryuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERIODUOM_Type }
     *     
     */
    public void setBILLEVERYUOM(PERIODUOM_Type value) {
        this.billeveryuom = value;
    }

    /**
     * Gets the value of the phaseimbalanceefficiencyloss1 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS1() {
        return phaseimbalanceefficiencyloss1;
    }

    /**
     * Sets the value of the phaseimbalanceefficiencyloss1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS1(QUANTITY value) {
        this.phaseimbalanceefficiencyloss1 = value;
    }

    /**
     * Gets the value of the phaseimbalanceefficiencyloss2 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS2() {
        return phaseimbalanceefficiencyloss2;
    }

    /**
     * Sets the value of the phaseimbalanceefficiencyloss2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS2(QUANTITY value) {
        this.phaseimbalanceefficiencyloss2 = value;
    }

    /**
     * Gets the value of the phaseimbalanceefficiencyloss3 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS3() {
        return phaseimbalanceefficiencyloss3;
    }

    /**
     * Sets the value of the phaseimbalanceefficiencyloss3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS3(QUANTITY value) {
        this.phaseimbalanceefficiencyloss3 = value;
    }

    /**
     * Gets the value of the phaseimbalanceefficiencyloss4 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS4() {
        return phaseimbalanceefficiencyloss4;
    }

    /**
     * Sets the value of the phaseimbalanceefficiencyloss4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS4(QUANTITY value) {
        this.phaseimbalanceefficiencyloss4 = value;
    }

    /**
     * Gets the value of the phaseimbalanceefficiencyloss5 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHASEIMBALANCEEFFICIENCYLOSS5() {
        return phaseimbalanceefficiencyloss5;
    }

    /**
     * Sets the value of the phaseimbalanceefficiencyloss5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHASEIMBALANCEEFFICIENCYLOSS5(QUANTITY value) {
        this.phaseimbalanceefficiencyloss5 = value;
    }

    /**
     * Gets the value of the performancemanager property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getPERFORMANCEMANAGER() {
        return performancemanager;
    }

    /**
     * Sets the value of the performancemanager property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setPERFORMANCEMANAGER(PERSONID_Type value) {
        this.performancemanager = value;
    }

    /**
     * Gets the value of the electricsubmeterinterval property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getELECTRICSUBMETERINTERVAL() {
        return electricsubmeterinterval;
    }

    /**
     * Sets the value of the electricsubmeterinterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setELECTRICSUBMETERINTERVAL(QUANTITY value) {
        this.electricsubmeterinterval = value;
    }

    /**
     * Gets the value of the electricusagethreshold property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getELECTRICUSAGETHRESHOLD() {
        return electricusagethreshold;
    }

    /**
     * Sets the value of the electricusagethreshold property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setELECTRICUSAGETHRESHOLD(QUANTITY value) {
        this.electricusagethreshold = value;
    }

}
